@@ -303,7 +303,13 @@ pub fn compiler(source: &str) -> Result<String, ParseError> {
                     in_either = false;
                     let inner_tokens = stack.join("|");
                     stack.clear();
-                    Some(format!("({})", inner_tokens))
+                    let current_group_quantifier = group_quantifier;
+                    group_quantifier = None;
+                    handle_quantifier(
+                        format!("({})", inner_tokens),
+                        current_group_quantifier,
+                        false,
+                    )
                 } else {
                     None
                 }
@@ -371,9 +377,9 @@ pub fn compiler(source: &str) -> Result<String, ParseError> {
         if let Some(formatted_token) = formatted_token {
             if in_either {
                 stack.push(formatted_token);
-                continue;
+            } else {
+                output.push_str(&formatted_token);
             }
-            output.push_str(&formatted_token);
         }
     }
 
